import { IUserSource } from '@cloudbase/weda-node-sdk';
import { ROUTE_NAMES } from './routes';
/**
 * 通过callFunction方式调用本云函数入参
 */
export interface ICloudFnParams {
    /**
     * 路由模块名称
     *  使用 ROUTE_NAMES 的 key, 或者直接使用 router 的值 均可, 默认值为 ROUTE_NAMES.datasource (数据源)
     */
    mode?: (keyof typeof ROUTE_NAMES) | string;
    /**
     * 数据源名称
     *  仅当 mode 为 ROUTE_NAMES.datasource (数据源) 有意义
     */
    dataSourceName?: string;
    /**
     * 方法名称
     *  仅当 mode 为 ROUTE_NAMES.datasource(数据源) 或 ROUTE_NAMES.common(公共模块) 有意义
     */
    methodName?: string;
    /**
     * 方法的默认参数
     *  仅当调用数据源方法时有意义
     */
    defaultParams?: any;
    /**
     * 数据库数据源的viewId, 记录数据源版本信息
     *  仅调用数据源方法时有意义
     *  已废弃, 后端将使用最新的数据源版本
     * @deprecated
     */
    viewId?: string;
    /**
     * 方法参数
     *  各个模块均需要参数, 参数根据调用的方法而异, 部分方法不需要参数
     */
    params?: any;
    /**
     * 调用的引用环境类型
     *  pre: 预览环境
     *  prod: 正式环境
     *
     * 在云开发的环境变量中若无法通过 IS_PREVIEW 当前环境是否为预览, 则使用该参数
     */
    envType?: 'pre' | 'prod';
    /**
     * 请求的微搭后台接入层地址, 可通过设置为 prod/pre 来指定地址
     * 可以是下边三个值
     *  'prod' 正式地址
     *  'pre' 预发地址
     *  url 任意一个url
     */
    wedaTarget?: string;
    /**
     * weda gateway 代理
     *  正常仅在本地开发模式需要设置该值
     */
    proxy?: string;
    /** 用户来源 */
    userSource?: IUserSource;
    /**
     * 其他额外信息
     *  包括 wx_ 打头的微信授权拿到的 cloudID
     */
    [k: string]: any;
}
export declare function main(event: any, context: any): Promise<string | object>;
