"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const call_datasource_1 = require("../../fns/call-datasource");
/**
 * 调用数据源方法
 *  ctx.path 格式为 /<dataSourceName>/<methodName>
 */
const restDataSource = async function restDataSource(ctx, next) {
    if (ctx.method !== 'POST')
        ctx.throw(405, 'method not allowed');
    await next();
    const params = ctx.request.body || {};
    const [dataSourceName, methodName] = ctx.path.replace(/^\//, '').split('/');
    const result = await call_datasource_1.callDataSource({
        dataSourceName,
        methodName,
        params,
    });
    // result 的值可能为 null,  koa 中将 ctx.body 设置为 null 即表示将body清空, 后续对其再设置将无效
    //  ref: https://github.com/koajs/koa/issues/998
    if (result !== null)
        ctx.body = result;
};
exports.default = restDataSource;
